@@ -10,12 +10,12 @@ __docformat__ = 'restructuredtext en'
 
 from cubes.addressbook import geocoding
 
-from cubicweb.selectors import implements
+from cubicweb.selectors import is_instance
 from cubicweb.server.hook import Hook
 
 class AutoSetLatLng(Hook):
     __regid__ = 'auto_lat_lng_hook'
-    __select__ = implements('PostalAddress')
+    __select__ = is_instance('PostalAddress')
     events = ('before_add_entity', 'before_update_entity')
 
     def __call__(self):
